package T2t::ExcelTranslator;

use strict;
use warnings;

use T2t::UserPreferencesCache;
use T2t::Utilities;
use T2t::Translator;
use Data::Dumper;
use T2t::Row;

our @ISA = qw(T2t::Translator);

sub new
{
    my $package  = shift;
    bless( {}, $package );
}

##
#	creates the tables from the input
#   @param file		file to be translated
##
sub makeTable				# creates the tables and outputs them
{
	my $self = shift;
	my $file = $self->getFile();		# input filename
	
	eval 'use Spreadsheet::ParseExcel';
	if( $@ )
	{
		warnMessage("Unable to process $file, Spreadsheet::ParseExcel must be installed.\n");
		return;
	}
	
	eval 'use Spreadsheet::ParseExcel::Workbook';

	dieMessage "No file specified\n" if( ! $file );

	my $out  = $self->getOutFilename();

	my $prefs = $self->getPreferencesCache();

	if( ! $prefs->isOverwrite() && -e $out )
	{
		warnMessage("Not overwriting file $out\n");
		return;
	}
	
	open(OUT,">$out") || dieMessage "Cannot open output : $out\n";
  	$self->openingHTML(\*OUT) if( ! $prefs->isTablesOnly() );

	my $excel = Spreadsheet::ParseExcel::Workbook->Parse($file);
	
  	# create and initialize the table object
  	my $table = $self->createTable();

	foreach my $sheet (@{$excel->{Worksheet}}) 
	{
		$sheet->{MaxRow} ||= $sheet->{MinRow};
		
		next if ! $sheet->{MaxRow};
		 
		foreach my $row ($sheet->{MinRow} .. $sheet->{MaxRow}) 
		{
			my @cellData = ();
			
			$sheet->{MaxCol} ||= $sheet->{MinCol};
			foreach my $col ($sheet->{MinCol} ..  $sheet->{MaxCol}) 
			{
				my $cell = $sheet->{Cells}[$row][$col];
				push( @cellData, $cell->{Val}) if( $cell );
			}
			
			$table->addRow( new T2t::Row(\@cellData) );
		}
	}
	  
 	print OUT $table;
  	$self->closingHTML(\*OUT) if( ! $prefs->isTablesOnly() );

  	close OUT;
}

1;

__END__

=head NAME
 

=head1 SYNOPSIS
 use T2t:Translator;
 

=head1 ABSTRACT

Translator 

=head1 AUTHOR INFORMATION

Copyright 1996-2008, Steven Scholnick <steve@scholnick.net>  

t2t is published under LGPL.  See license.html for details

=cut

