package T2t::Head;

use strict;
use warnings;

use T2t::HTML_Element;
use T2t::UserPreferencesCache;
use T2t::Utilities;

use overload q{""} => \&toString;

our @ISA = qw( T2t::HTML_Element );

sub new
{
    my $package = shift;
    bless( { title => T2t::UserPreferencesCache::getInstance()->getTitle() }, $package );        
}

sub toString
{
    my $self  = shift;
    my $title = $self->getTitle();
    
    my $s = "<head>\n";
    
    if( T2t::UserPreferencesCache::getInstance()->isXHTML() )
    {
    	$s .= $self->getTab() . qq(<meta http-equiv="Content-Type" content="text/html; charset=iso-8859-1" />\n);
    }
    
   	$s   .= $self->getTab() . "<title>$title</title>\n";
   	$s   .= $self->getTab() .  qq(<meta name="generator" content="t2t" />\n);
    $s   .= getFileData( T2t::UserPreferencesCache::getInstance()->getStyleHeader() );
   	$s   .= "</head>\n\n";

    return $s;
}

sub getStyleSheet
{
    my $self = shift;
    my $preference = T2t::UserPreferencesCache::getInstance()->getStyleHeader();

    my $ret = "";
    
    if( -e $preference )
    {
	    local $/ = undef;
	    open(STYLE,$preference) || return "";
	    $ret = <STYLE>;	# slurp in the whole file
	    close STYLE;
    }
    else
    {
        $ret = $self->getTab() . "$preference\n";
    }
    
    return $ret;
}


sub getTitle 
{ 
	my $self = shift;
	return defined($self->{title}) ? $self->{title} : '';      
}

sub setTitle { $_[0]->{title} = $_[1]; }


1;

__END__

=head NAME
 Head - <head> section of HTML

=head1 SYNOPSIS
 use T2t:Head;
 
 Head is part of the T2t program collection.  It is used
 only to create and print out the <head> section

=head1 ABSTRACT

=head1 AUTHOR INFORMATION

Copyright 2000-2008, Steven Scholnick <steve@scholnick.net>  

t2t is published under LGPL.  See license.html for details
