package T2t::TextFileTranslator;

use strict;
use warnings;

use T2t::Row;
use T2t::UserPreferencesCache;
use T2t::Utilities;
use T2t::Translator;

our @ISA     = qw(T2t::Translator);
our $VERSION = '1.00';

sub new
{
    my $package  = shift;
    bless( {}, $package );
}

##
#	creates the tables from the input
#   @param file		file to be translated
##
sub makeTable				# creates the tables and outputs them
{
	my $self  = shift;
	my $file  = $self->getFile();		# input filename
	my $prefs = $self->getPreferencesCache();

    my $out  = ">&STDOUT";	# default to stdout

	if( $file )
	{
		$out  = $self->getOutFilename();

		if( ! $prefs->isOverwrite() && -e $out )
		{
			warnMessage("Not overwriting file $out\n");
			return;
		}
		
	    open(STDIN,$file) || dieMessage "Cannot open input : $file\n";
  	}
 
	open(OUT,">$out") || dieMessage "Cannot open output : $out\n";

  	$self->openingHTML(\*OUT) if( ! $prefs->isTablesOnly() );

	# create an easy reference to the delimiter
  	my $delim = $prefs->getDelimiter();
   
  	# create and initialize the table object
  	my $table = $self->createTable();

  	while( <STDIN> )
  	{
    	chomp;
    	next if( $prefs->isDashes() && /-----|_____/ );
     
     	s/  */ /g;		# 2 or more spaces to one
     
     	if( $prefs->isSqueeze() )
     	{
     		s/$delim$delim*/$delim/g;
     		chop if( /$delim$/ );				# handle a line with a final delimiter
     	}

     	if( /$delim/ )
     	{
			my @cellData = split($delim, $_);
			$table->addRow( new T2t::Row(\@cellData) );
     	}
     	else
     	{
        	if( $prefs->isOneTable() )  		# just one table, just add a blank line
        	{	
        		my @cellData = ('') x $table->getNumberOfColumns();
				$table->addRow( new T2t::Row(\@cellData) );
        	}
        	else 								# dump the line to the output
        	{
				print OUT $table;
				$table = $self->createTable();	# create a new table
				print OUT "$_\n";
        	}
     	}
  	}

  	close( STDIN );
  
   	print OUT $table;
  
  	$self->closingHTML(\*OUT) if( ! $prefs->isTablesOnly() );

  	close OUT;
}

1;

__END__

=head NAME
 Translator - the engine of T2t package

=head1 SYNOPSIS
 use T2t:Translator;
 
 Translator is the main class of the T2t package; it is the engine of T2t package.  It performs
 the conversion from text to HTML.  Translator is currently very tied to its t2t frontend.  All
 incoming data (filenames, directories, preferences, etc) come through the preferences map.  This
 may change in the future.

=head1 ABSTRACT

Translator 

=head1 AUTHOR INFORMATION

Copyright 1996-2008, Steven Scholnick <steve@scholnick.net>  

t2t is published under LGPL.  See license.html for details

=cut

