package T2t::Translator;

use strict;
use warnings;

use Cwd;

use T2t::BaseClass;
use T2t::Head;
use T2t::Table;
use T2t::Body;
use T2t::Row;
use T2t::Cell;
use T2t::UserPreferencesCache;
use T2t::Utilities;

use overload q{""} => \&toString;

our @ISA  = qw(T2t::BaseClass);

sub new
{
    my $package = shift;
    my $self    = {};
    
    $self->{file} = shift;
    
    bless( $self, $package );
}

sub toString
{
	my $self = shift;
	
	return ref($self) . " : " . ( $self->getFile() ? $self->getFile() : "stdin" ); 
}

sub setFile		{  $_[0]->{file} = $_[1]; }
sub getFile 	{  $_[0]->{file}; }


##
#	returns the output filepath
#   @param file		file to be translated
##
sub getOutFilename
{
	my $self = shift;
	
	my $out = $self->getFile();
	my $ri  = rindex($self->getFile(),".");

	if( $ri > -1 ) 
	{
		my $exten = substr($self->getFile(),$ri);   # get the extension
		$out =~ s/$exten/.html/;         			# replace the extension
	}
	else
	{
	   	$out = "$out.html";
	}
	
	$out;
}

##
#	creates the tables from the input
#   @param file		file to be translated
##
sub makeTable				# creates the tables and outputs them
{
	die "Must override";
}

##
#	creates a Table object
##
sub createTable
{
	return new T2t::Table();
}

##
#	prints the opening HTML statements to the specified file handle
#   @param FH		file handle reference
##
sub openingHTML
{
	my $self = shift;
   	my $FH   = shift || return;
	
	my $title = T2t::UserPreferencesCache::getInstance()->getTitle() || "";
   	
   	if( T2t::UserPreferencesCache::getInstance()->isXHTML() )
   	{
		print $FH qq(<?xml version="1.0" encoding="iso-8859-1"?>\n);
		print $FH qq(<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">\n);
		print $FH qq(<html xmlns="http://www.w3.org/1999/xhtml" xml:lang="en" lang="en">\n\n);
   	}
   	else
   	{
   		print $FH qq(<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN" "http://www.w3.org/TR/html4/loose.dtd">\n\n);
   		print $FH "<html>\n";
   	}
   	
   	print $FH new T2t::Head();
   
   	print $FH new T2t::Body();
   	print $FH "<h1>$title</h1>\n" if T2t::UserPreferencesCache::getInstance()->isCreateH1();
   
   	print $FH getFileData( T2t::UserPreferencesCache::getInstance()->getTop() );
}

##
#   PRIVATE method
#	prints the closing HTML statements to the specified file handle
#   @param FH		file handle reference
##
sub closingHTML		# closing html statements
{
	my $self = shift;
   	my $FH   = shift || return;

   	printFile( T2t::UserPreferencesCache::getInstance()->getBottom(), $FH );
   	print $FH "\n\n</body>\n</html>\n";
}


1;

__END__

=head NAME
 Translator - Base class for translators

=head1 SYNOPSIS
 use T2t:Translator;
 
 

=head1 ABSTRACT

Translator 

=head1 AUTHOR INFORMATION

Copyright 1996-2008, Steven Scholnick <steve@scholnick.net>  

t2t is published under LGPL.  See license.html for details

=cut

