package T2t::Utilities;

require Exporter;

use strict;
use warnings;

our @ISA = qw(Exporter);

our @EXPORT = qw(trim cleanArguments getPath getResourceFilePath printFile getFileData
                 getFileAsArray message warnMessage dieMessage expandPath);

sub getFileData
{
	my $filePath = shift;
	
	return "" if( ! $filePath );
	
	$filePath = expandPath( $filePath );
	
    my $ret = "";
    
    if( -e $filePath )
    {
	    local $/ = undef;
	    open(STYLE,$filePath) || return "";
	    $ret = <STYLE>;	                           # slurp in the whole file
	    close STYLE;
    }
    
    $ret;
}

sub expandPath
{
	my $path = shift;
	
	return $path if $path !~ /^~/;
	
	my $home = $ENV{"HOME"};
	
	warnMessage( "HOME is not set" ) if ! $home;
	
	$path =~ s/~/$home/;
	
	$path;
}


#	returns the RC file path
sub getResourceFilePath
{
	my $unixStyle  = shift;						# unix rc file naming, eg .t2trc
	my $otherStyle = shift; 					# win rc file, eg t2t.rc

	warnMessage( "HOME is not set" ) if ! $ENV{"HOME"};
	
  	# first try unix style
  	my $initPath = getPath($ENV{"HOME"},$unixStyle);
  
  	# if not there, try others style
  	$initPath = getPath($ENV{"HOME"},$otherStyle) if( ! -e $initPath );
  
 	if( -e $initPath )
  	{
  		return $initPath;
    }
    else
    {
     	return undef;
    }
}

sub getFileAsArray			# returns a whole file as an array text lines
{
	my $file = shift;
	
	my @lines;

	open(IN,$file) || return @lines;
	while( <IN> )
	{
		chomp;
		next if /^$/;
		push(@lines,$_);
	}
	close IN;
	
	@lines;
}

sub trim  # trims whitespace
{
    local $_ = shift;
    s/^\s+//;
    s/\s+$//;
    $_;
}

sub printFile    # prints a file verbatim to the specified file handle
{
   my $file = shift || return;
   my $FH   = shift || return;
   
   open(INP,$file) || return;
   print $FH $_ while( <INP> );
   close INP;
}

sub getPath   # returns a full path
{
   my $dir      = shift;
   my $filename = shift;

   if( $filename =~ m!^/! )     # check for a fully-qualified path
   {
       return $filename;
   }

   return "$dir/$filename";
}

sub cleanArguments
{
	my @args = @_;
	foreach ( @args )
	{
		$_ = '' if( ! $_ );
	}
	
	return @args;
}

sub message
{
	return if isQuiet() || ! isVerbose();

	print STDOUT 't2t : ' . join(' ',cleanArguments(@_));
}

sub warnMessage
{
	return if isQuiet();

	print STDERR 't2t : ' . join(' ',cleanArguments(@_));
}

sub dieMessage
{
	print STDERR 't2t : ' . join(' ',cleanArguments(@_));
	exit -1;
}

sub isQuiet	
{
    return T2t::UserPreferencesCache::getInstance()->isQuiet();
}

sub isVerbose	
{
    return T2t::UserPreferencesCache::getInstance()->isVerbose();
}


1;

__END__

=head NAME
Utilities - helper class.

=head1 SYNOPSIS
use T2t::Utilities;
 
Utilities is comprised of static helper methods. 
 
=head1 ABSTRACT

Utilities 

=head1 AUTHOR INFORMATION

Copyright 2000-2008, Steven Scholnick <steve@scholnick.net>  

t2t is published under LGPL.  See license.html for details

Address bug reports and comments to:
steve@scholnick.net

t2t Home Page:
http://www.scholnick.net/t2t

=cut

